@@ -43,7 +43,9 @@ class Client(object):
 
     def call_method(self, method, param=None):
         """Calls an API method."""
-        for attempt in range(5):
+        for attempt in range(10):
+            delay = 5 * (attemp + 1)
+
             try:
                 payload = {"method": method, "application_id": self.application_id,
                     "login": self.login, "token": self.auth_token}
@@ -60,19 +62,24 @@ class Client(object):
                         raise AuthError(data["error_str"])
                     elif data["error_code"] == 1:
                         raise BadCampaignError(data["error_str"])
+                    elif data["error_code"] == 52:  # login temporary unavailable
+                        delay = 30
+                        raise RuntimeError(data["error_str"])
+
                     message = data["error_detail"]
                     if data["error_str"]:
                         if message:
                             message += "; "
                         message += data["error_str"]
                     raise Error("Error %s calling method %s: %s" % (data["error_code"], method, message))
+
                 if "data" not in data:
                     raise Error("Yandex.API response has no \"data\" block.")
+
                 return data["data"]
             except Error:
                 raise
             except Exception, e:
-                delay = 5 * (attempt + 1)
                 self.logger.exception("Error, will retry in %u seconds: %s" % (delay, e))
                 time.sleep(delay)
 
